#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 list-t
version:              1.0.5.7
visibility:           public
id:                   list-t-1.0.5.7-LOmD8fXDPU7JNqCszGe6HS
key:                  list-t-1.0.5.7-LOmD8fXDPU7JNqCszGe6HS
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/list-t
synopsis:             ListT done right
description:
    A correct implementation of the list monad-transformer.
    Useful for basic streaming.

category:             Streaming, Data Structures, Control
abi:                  fe2d0304427952b1cd3a7d418d2d9324
exposed:              True
exposed-modules:      ListT
hidden-modules:       ListT.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/list-t-1.0.5.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/list-t-1.0.5.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/list-t-1.0.5.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-list-t
hs-libraries:         HSlist-t-1.0.5.7-LOmD8fXDPU7JNqCszGe6HS
depends:
    base-4.18.2.1 foldl-1.4.18-LZjdtEkL5CG5LqlrhJKWDJ
    logict-0.8.2.0-L4eu98jHQVLA3qovtFW3cU
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH
    monad-control-1.0.3.1-HEBTl9nyvCw8RVIFf0VVRN mtl-2.3.1
    transformers-0.6.1.0
    transformers-base-0.4.6.1-Co00iLdHKr9L59m96o0741

haddock-interfaces:   /usr/share/doc/haskell-list-t/html/list-t.haddock
haddock-html:         /usr/share/doc/haskell-list-t/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

